summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoPen.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficeui/KoPen.h')
-rw-r--r--lib/kofficeui/KoPen.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/kofficeui/KoPen.h b/lib/kofficeui/KoPen.h
index 87124cef9..84a7ea668 100644
--- a/lib/kofficeui/KoPen.h
+++ b/lib/kofficeui/KoPen.h
@@ -20,19 +20,19 @@
#ifndef KOPEN_H
#define KOPEN_H
-#include <qpen.h>
+#include <tqpen.h>
class KoZoomHandler;
/**
* Pen that handles line widths in points
*/
-class KoPen : public QPen
+class KoPen : public TQPen
{
public:
KoPen();
- KoPen(const QColor& _color, double _pointWidth, Qt::PenStyle _style);
- KoPen(const QColor& _color);
+ KoPen(const TQColor& _color, double _pointWidth, Qt::PenStyle _style);
+ KoPen(const TQColor& _color);
~KoPen();
/**
@@ -58,8 +58,8 @@ class KoPen : public QPen
/// KoPen width in points
double pointWidth() const { return m_pointWidth; }
- /// Returns a zoomed QPen
- QPen zoomedPen(KoZoomHandler* zoomHandler);
+ /// Returns a zoomed TQPen
+ TQPen zoomedPen(KoZoomHandler* zoomHandler);
private:
double m_pointWidth;